==> rook_users-0.0.1.tar.gz: example/README.md <==
## Example with a dedicated widget

### rook_user_status.dart

```dart
import 'package:flutter/material.dart';
import 'package:rook_users/rook_users.dart';

class RookUserStatus extends StatefulWidget {
  const RookUserStatus({Key? key}) : super(key: key);

  @override
  State<RookUserStatus> createState() => _RookUserStatusState();
}

class _RookUserStatusState extends State<RookUserStatus> {
  final RookUsersManager manager = RookUsersManager(
    UsersSecrets.url,
  );

  bool loading = false;
  bool registered = false;
  RookUser? rookUser;
  String? error;

  @override
  void initState() {
    initialize();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      alignment: Alignment.center,
      child: loading
          ? const CircularProgressIndicator()
          : Column(
        children: [
          if (registered)
            Row(
              children: [
                const Icon(Icons.verified_rounded),
                const SizedBox(width: 10),
                Expanded(
                  child: Text(
                    '${rookUser?.type.name.toUpperCase()} USER: ${rookUser?.id} is registered!',
                  ),
                ),
              ],
            ),
          if (!registered) Text('Error: $error'),
          if (!registered) const SizedBox(height: 20),
          if (!registered)
            ElevatedButton(
              onPressed: initialize,
              child: const Text('Try again'),
            ),
        ],
      ),
    );
  }

  void initialize() async {
    setState(() => loading = true);
    try {
      await Future.delayed(const Duration(seconds: 1));

      final user = await manager.registerRookUser(
        UsersSecrets.clientUUID,
        UsersSecrets.userID,
        UserType.healthConnect,
      );

      setState(() {
        loading = false;
        registered = true;
        rookUser = user;
        error = null;
      });
    } catch (e) {
      setState(() {
        loading = false;
        registered = false;
        error = 'Error: $e';
      });
    }
  }
}
```

## Example with demo app

1. Download the project from
   our [repository](https://github.com/RookeriesDevelopment/rook_extraction_demo_app_flutter ).

2. In the lib folder create a secrets.dart file with a Secrets class and add the following
   constants:

```dart
class Secrets {
  static const String rookApiUrl = 'YOUR_API_URL';
  static const String rookClientUUID = 'YOUR_CLIENT_UUID';
}
```

3. In the lib folder create a transmission_secrets.dart file with a TransmissionSecrets class and
   add the following constants:

```dart
class TransmissionSecrets {
  static const String url = 'API_URL';
  static const String clientUUID = 'CLIENT_UUID';
  static const String clientPassword = 'CLIENT_PASSWORD';
}
```

* If you won't be using the [rook_transmission](https://pub.dev/packages/rook_transmission) package
  you can assign `google.com` to `url` and `N/A` to `clientUUID` and `clientPassword`.

4. In the lib folder create a users_secrets.dart file with a UsersSecrets class and
   add the following constants:

```dart
class UsersSecrets {
  static const url = 'API_URL';
  static const String clientUUID = 'CLIENT_UUID';
  static const userID = 'USER_UNIQUE_IDENTIFIER';
}
```

* `userID` is defined by you, so feel free to use the same ID your app uses to identify it's users.

5. Run `flutter pub get`

==> rook_users-0.1.0.tar.gz: example/README.md <==
## Example with a dedicated widget

### rook_user_status.dart

```dart
import 'package:flutter/material.dart';
import 'package:rook_users/rook_users.dart';

class RookUserStatus extends StatefulWidget {
  const RookUserStatus({Key? key}) : super(key: key);

  @override
  State<RookUserStatus> createState() => _RookUserStatusState();
}

class _RookUserStatusState extends State<RookUserStatus> {
  final RookUsersManager manager = RookUsersManager(
    Secrets.rookUrl,
    Secrets.clientUUID,
    Secrets.clientPassword,
  );

  bool loading = false;
  bool registered = false;
  RookUser? rookUser;
  String? error;

  @override
  void initState() {
    initialize();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      alignment: Alignment.center,
      child: loading
          ? const CircularProgressIndicator()
          : Column(
        children: [
          if (registered)
            Row(
              children: [
                const Icon(Icons.verified_rounded),
                const SizedBox(width: 10),
                Expanded(
                  child: Text(
                    '${rookUser?.type.name.toUpperCase()} USER: ${rookUser?.id} is registered!',
                  ),
                ),
              ],
            ),
          if (!registered) Text('Error: $error'),
          if (!registered) const SizedBox(height: 20),
          if (!registered)
            ElevatedButton(
              onPressed: initialize,
              child: const Text('Try again'),
            ),
        ],
      ),
    );
  }

  void initialize() async {
    setState(() => loading = true);
    try {
      await Future.delayed(const Duration(seconds: 1));

      final user = await manager.registerRookUser(
        Secrets.userID,
        UserType.healthConnect,
      );

      setState(() {
        loading = false;
        registered = true;
        rookUser = user;
        error = null;
      });
    } catch (e) {
      setState(() {
        loading = false;
        registered = false;
        error = 'Error: $e';
      });
    }
  }
}
```

## Example with demo app

1. Download the project from
   our [repository](https://github.com/RookeriesDevelopment/rook_demo_app_flutter).

2. In the lib folder create a secrets.dart file with a Secrets class and add the following
   constants:

```dart
class Secrets {
  static const String rookAuthUrl = 'rookAuthUrl';
  static const String userID = 'userID';
  static const String clientUUID = 'clientUUID';
  static const String clientPassword = 'clientPassword';
  static const String rookUrl = 'rookUrl';
}
```

* `userID` is defined by you, so feel free to use the same ID your app uses to identify it's users.

3. Run `flutter pub get`
